ActionMode

Enum ActionMode 

pub enum ActionMode {
    Push,
    Pull,
}
Indicates the tendril action to be performed.

Variants



Push

Copy/symlink tendrils from the Tendrils repo to their various locations on the computer.



Pull

Copy tendrils from their various locations on the computer to the Tendrils repo.