pub enum GetConfigError {
IoError {
cfg_type: ConfigType,
kind: ErrorKind,
},
ParseError {
cfg_type: ConfigType,
msg: String,
},
}Expand description
Indicates an error while reading/parsing a configuration file.
Variants
IoError
A general file system error while reading the file.
ParseError
An error while parsing the json from the file.
Implementations
Sourceimpl GetConfigError
impl GetConfigError
Sourcepub fn with_cfg_type(self, cfg_type: ConfigType) -> GetConfigError
pub fn with_cfg_type(self, cfg_type: ConfigType) -> GetConfigError
Copies the error with the updated cfg_type