pub enum GetTendrilsRepoError {
GivenInvalid {
path: PathBuf,
},
DefaultInvalid {
path: PathBuf,
},
DefaultNotSet,
ConfigError(GetConfigError),
}Expand description
Indicates an error while determining the Tendrils repo to use.
Variants
GivenInvalid
The given path is not a valid Tendrils repo.
DefaultInvalid
The default Tendrils repo is not a valid Tendrils repo.
DefaultNotSet
The default Tendrils repo is not set.
ConfigError(GetConfigError)
A general error while reading the global configuration file.