pub enum InitError {
IoError {
kind: ErrorKind,
},
AlreadyInitialized,
NotEmpty,
}Expand description
Indicates an error while initializing a new Tendrils repo.
Variants
IoError
A general file system error
AlreadyInitialized
The folder to initialize is already a Tendrils repo
NotEmpty
The folder to initialize is not empty.