pub enum SetupError {
CannotSymlink,
ConfigError(GetConfigError),
NoValidTendrilsRepo(GetTendrilsRepoError),
}Expand description
Indicates an error with the setup of a Tendrils repo.
Variants
CannotSymlink
The runtime context on Windows does not permit creating symlinks.
ConfigError(GetConfigError)
An error in importing the configuration.
NoValidTendrilsRepo(GetTendrilsRepoError)
No valid Tendrils repo was found.