TendrilActionError

Enum TendrilActionError 

pub enum TendrilActionError {
    IoError {
        kind: ErrorKind,
        loc: Location,
    },
    ModeMismatch,
    TypeMismatch {
        mistype: FsoType,
        loc: Location,
    },
}
Indicates an unsuccessful tendril action.

Variants



IoError

General file system errors loc indicates which side of the action had the unexpected type, as indicated by mistype

Fields

kind: ErrorKind

The type of error that occured

loc: Location

Where the error occured



ModeMismatch

The tendril mode does not match the attempted action, such as:

  • Attempting to pull a link-type tendril
  • Attempting to link a copy-type tendril


TypeMismatch

The type of the remote and local file system objects do not match, or do not match the expected types, such as:

  • The source is a file but the destination is a folder
  • The local or remote are symlinks (during a push/pull action)
  • The remote is not a symlink (during a link action)

Fields

mistype: FsoType

The unexpected type that was found

loc: Location

Where the unexpected type was found