pub enum TendrilActionSuccess {
New,
Overwrite,
NewSkipped,
OverwriteSkipped,
}Expand description
Indicates a successful tendril action.
Variants
New
A successful action that created a new file system object at the destination.
Overwrite
A successful action that overwrote a file system object at the destination.
NewSkipped
An action that was expected to succeed in creating a new file system object at the destination but was skipped due to a dry-run.
OverwriteSkipped
An action that was expected to succeed in overwriting a file system object at the destination but was skipped due to a dry-run.