pub struct TendrilReport<T: TendrilLog> {
pub raw_tendril: RawTendril,
pub log: Result<T, InvalidTendrilError>,
}Expand description
Generic report format for any operation on a RawTendril
Fields
raw_tendril: RawTendrilThe original tendril bundle that this tendril was expanded from.
log: Result<T, InvalidTendrilError>Result containing the log from the operation, provided
the tendril was valid.
Otherwise, it contains the InvalidTendrilError.