pub struct TendrilsActor {}Trait Implementations
Sourceimpl TendrilsApi for TendrilsActor
impl TendrilsApi for TendrilsActor
Sourcefn get_default_repo_path(&self) -> Result<Option<PathBuf>, GetConfigError>
fn get_default_repo_path(&self) -> Result<Option<PathBuf>, GetConfigError>
Returns the
default-repo-path value stored in
~/.tendrils/global-config.json or any errors that
occur. Returns None if the value is blank or absent, or if the config
file does not exist. Note: This does not check whether the folder
is a tendrils repo.Sourcefn get_default_profiles(&self) -> Result<Option<Vec<String>>, GetConfigError>
fn get_default_profiles(&self) -> Result<Option<Vec<String>>, GetConfigError>
Returns the
default-profiles stored in
~/.tendrils/global-config.json or any errors that
occur. Returns None if the value is blank or absent, or if the config
file does not exist.Sourcefn init_tendrils_repo(
&self,
dir: &UniPath,
force: bool,
) -> Result<(), InitError>
fn init_tendrils_repo( &self, dir: &UniPath, force: bool, ) -> Result<(), InitError>
Initializes a Tendrils repo with a
.tendrils folder and a
pre-populated tendrils.json file. This will fail if the folder is
already a Tendrils repo or if there are general file-system errors.
This will also fail if the folder is not empty and force is false. Read moreSourcefn is_tendrils_repo(&self, dir: &UniPath) -> bool
fn is_tendrils_repo(&self, dir: &UniPath) -> bool
fn list_tendrils( &self, td_repo: Option<&UniPath>, filter: FilterSpec, ) -> Result<Vec<TendrilReport<ListLog>>, SetupError>
Sourcefn tendril_action_updating<U>(
&self,
updater: U,
mode: ActionMode,
td_repo: Option<&UniPath>,
filter: FilterSpec,
dry_run: bool,
force: bool,
) -> Result<(), SetupError>where
U: UpdateHandler<ActionLog>,
fn tendril_action_updating<U>(
&self,
updater: U,
mode: ActionMode,
td_repo: Option<&UniPath>,
filter: FilterSpec,
dry_run: bool,
force: bool,
) -> Result<(), SetupError>where
U: UpdateHandler<ActionLog>,
Reads the
tendrils.json file in the given Tendrils repo, and
performs the action on each tendril that matches the
filter. Read moreSourcefn tendril_action(
&self,
mode: ActionMode,
td_repo: Option<&UniPath>,
filter: FilterSpec,
dry_run: bool,
force: bool,
) -> Result<Vec<TendrilReport<ActionLog>>, SetupError>
fn tendril_action( &self, mode: ActionMode, td_repo: Option<&UniPath>, filter: FilterSpec, dry_run: bool, force: bool, ) -> Result<Vec<TendrilReport<ActionLog>>, SetupError>
Same behaviour as
tendril_action_updating except reports are only
returned once all actions have completed.Auto Trait Implementations
impl Freeze for TendrilsActor
impl RefUnwindSafe for TendrilsActor
impl Send for TendrilsActor
impl Sync for TendrilsActor
impl Unpin for TendrilsActor
impl UnsafeUnpin for TendrilsActor
impl UnwindSafe for TendrilsActor