UniPath

Struct UniPath 

pub struct UniPath(/* private fields */);
A PathBuf wrapper that guarantees that the path has been resolved in this particular order: 1. Any environment variables have been resolved 2. A leading tilde has been resolved 3. A non-rooted path has been rooted. The default conversion to rooted occurs by prepending / on Unix or \ on Windows. A different root can be provided by constructing the UniPath using UniPath::new_with_root. 4. Unix style path separators (/) have been replaced with \ (Windows only)

Implementations

Source

impl UniPath

pub fn new_with_root(path: &Path, root: &Path) -> Self

Converts the given path to a UniPath using the standard rules, but converts relative paths to absolute by appending them to the given root. If the given root is not absolute either, it will default to using / on Unix and \ on Windows.

pub fn inner(&self) -> &Path

The wrapped PathBuf that has been sanitized.