UpdateHandler

Trait UpdateHandler 

pub trait UpdateHandler<L>
where L: TendrilLog,
{ // Required methods fn count(&mut self, value: i32); fn before(&mut self, raw: RawTendril); fn after(&mut self, report: TendrilReport<L>); }
Contains various updater functions for live feedback during a tendrils command.

Required Methods

fn count(&mut self, value: i32)

Accepts value indicating the total count of all raw tendrils that will be processed.

fn before(&mut self, raw: RawTendril)

Accepts raw indicating the tendril that will be processed. This is called before processing.

fn after(&mut self, report: TendrilReport<L>)

Accepts report containing the result of the operation. This is called after processing.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<A, B, C, L> UpdateHandler<L> for CallbackUpdater<A, B, C, L>
where A: FnMut(TendrilReport<L>), B: FnMut(RawTendril), C: FnMut(i32), L: TendrilLog,