pub enum TendrilActionError {
IoError {
kind: ErrorKind,
loc: Location,
},
ModeMismatch,
TypeMismatch {
mistype: FsoType,
loc: Location,
},
}Expand description
Indicates an unsuccessful tendril action.
Variants
IoError
General file system errors
loc indicates which side of the action had the unexpected type,
as indicated by mistype
ModeMismatch
The tendril mode does not match the attempted action, such as:
- Attempting to pull a link-type tendril
- Attempting to link a copy-type tendril
TypeMismatch
The type of the remote and local file system objects do not match, or do not match the expected types, such as:
- The source is a file but the destination is a folder
- The local or remote are symlinks (during a push/pull action)
- The remote is not a symlink (during a link action)