pub enum TendrilMode {
CopyMerge,
CopyOverwrite,
Link,
}Expand description
Indicates the behaviour of this tendril, and determines whether it is a copy-type, or a link-type tendril.
Variants
CopyMerge
Overwrite any files/folders that are present in both the source and destination, but keep anything in the destination folder that is not in the source folder. This only applies to folder tendrils. Tendrils with this mode are considered copy-type.
CopyOverwrite
Completely overwrite the destination folder with the contents of the source folder. This only applies to folder tendrils. Tendrils with this mode are considered copy-type.
Link
Create a symlink at the remote location that points to local file/folder.
Implementations
Sourceimpl TendrilMode
impl TendrilMode
pub fn requires_symlink(&self) -> bool